petfinder-api
=============

:Author: Greg Taylor
:License: BSD

This is a simple Python wrapper to Petfinder.com's XML API.

Documentation
-------------

Full documentation is located at http://petfinder-api.readthedocs.org/

License
-------

This project, and all contributed code, are licensed under the BSD License.
A copy of the BSD License may be found in the repository.
